#!/usr/bin/env node

const fs = require('fs')
const program = require('commander')
const { serializeTaxonomy } = require('../index.js')
const { values } = require('../lib/utils.js')

var chalk = require('chalk')


program
  .arguments('<file>')
  .action(function (file, env) {
    const format = file.match(/\.ndjson$/) ? 'ndjson' : 'json'
    const json = fs.readFileSync(file, 'utf8')
    var kos = {}

    if (format === 'json') {
      kos = JSON.parse(json)
      if (typeof kos === 'array') {
        kos = { concepts: kos }
      }
    } else {
      var concepts = json.split(/\r?\n/).filter(line => line).map(JSON.parse)
      kos = { concepts: concepts }
    }

    if (!kos.topConcepts) {
      kos.topConcepts = values(kos.concepts)
        .filter(c => {
          return !c.broader || !c.broader.length
        })
        .map(c => { return { uri: c.uri }})
    }

    // TODO: find language used in kos
    kos.languages = ['de']


    // serialize taxonomy to stream
    var options = { chalk: chalk }
    serializeTaxonomy.text(kos, process.stdout, options)
    //process.stdout.write(JSON.stringify(kos, null, 2) + '\n')
  })
  .parse(process.argv)

